cygl
====

Open GL cython definitions and utils. Glew.pxd files is auto generated from glew.h

##Dependecies:
GLEW (OpengGL Extension Wrangler)
* Linux: `sudo apt-get install libglew-dev`
* MacOS: `brew install glew`
* Win 'insert win instructions here.'

##Build
* run 'python setup.py install' (may require sudo)
* please raise an issue if this does not work for you
